@@ -206,8 +206,6 @@ pub mod patched_printer_profile_request;
 pub use self::patched_printer_profile_request::PatchedPrinterProfileRequest;
 pub mod patched_remote_control_command_request;
 pub use self::patched_remote_control_command_request::PatchedRemoteControlCommandRequest;
-pub mod patched_task_status_request;
-pub use self::patched_task_status_request::PatchedTaskStatusRequest;
 pub mod patched_user_request;
 pub use self::patched_user_request::PatchedUserRequest;
 pub mod print_job_event;
@@ -258,8 +256,6 @@ pub mod remote_control_command_request;
 pub use self::remote_control_command_request::RemoteControlCommandRequest;
 pub mod software_enum;
 pub use self::software_enum::SoftwareEnum;
-pub mod status_enum;
-pub use self::status_enum::StatusEnum;
 pub mod task;
 pub use self::task::Task;
 pub mod task_request;
@@ -268,6 +264,8 @@ pub mod task_status;
 pub use self::task_status::TaskStatus;
 pub mod task_status_request;
 pub use self::task_status_request::TaskStatusRequest;
+pub mod task_status_type;
+pub use self::task_status_type::TaskStatusType;
 pub mod task_type;
 pub use self::task_type::TaskType;
 pub mod telemetry_event;
